#!/opt/VRTSperl/bin/perl -w
#------------------------------------------------------------------
# $Copyright: Copyright (c) 2019 Veritas Technologies LLC.
# All rights reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND TRADE SECRETS OF
# VERITAS TECHNOLOGIES LLC.  USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED
# WITHOUT THE PRIOR EXPRESS WRITTEN PERMISSION OF VERITAS TECHNOLOGIES LLC.
#
# The  Licensed  Software  and  Documentation  are  deemed  to be commercial
# computer  software  as  defined  in  FAR  12.212 and subject to restricted
# rights  as  defined in FAR Section 52.227-19 "Commercial Computer Software
# - Restricted  Rights"  and  DFARS 227.7202,  et seq.  "Commercial Computer
# Software  and  Commercial Computer Software Documentation," as applicable,
# and any successor regulations, whether delivered by Veritas as on premises
# or  hosted  services.  Any  use,  modification,  reproduction  release,
# performance,  display  or  disclosure  of  the  Licensed  Software  and
# Documentation by the U.S. Government shall be solely in accordance with
# the terms of this Agreement. $
#
# $Header: $
#
# $Author: $
# $Date: $
# $Revision: $
#------------------------------------------------------------------

BEGIN {
  my $sVCSperl = undef;
  my $sVCSagntfwHome = "/opt/VRTS/.ACCLib";
  ( my $sDirName = $0 ) =~ s#(.*)/.*$#$1#;

  if ( $ENV { CLUSTER_HOME } ) { # VCS 5.0/VAD..
    $sVCSperl = "$ENV{CLUSTER_HOME}/lib";
  }
  else { # VCS..
    $sVCSperl = "/opt/VRTSperl/lib/site_perl";
  }

  unshift ( @INC, $sDirName,
                  "$sVCSagntfwHome/vcs",
                  "$sVCSagntfwHome/system",
                  "$sVCSagntfwHome/network",
                  $sVCSperl );
}
use strict;
use POSIX;
use Getopt::Std;
use Fcntl;
use File::Path qw ( mkpath );

use constant VCSLOGDIR => "/var/VRTSvcs/log";


#-------------------------------------------
# Create the Log Dir, If not already present
#-------------------------------------------

my %options = ();
getopts("e:c:a:u:r:b", \%options);


   my    $sCommand =  $options{c};
   my    $sCommandArgs =  $options{a};
   my    $sUser = $options{u};
   my    $sEnvFile = $options{e} if defined $options{e}; 
   my    $sResName = $options{r};
   my    $bIsBackground = defined $options{b} ? 1 : 0;

my $sLogDir = VCSLOGDIR . "/tmp/Informatica";

#--------------------------------------
# Open the log file for printing output
#--------------------------------------
my @lsOsDetails = uname ();
my $sTime = strftime '%Y/%m/%d %H:%M:%S', localtime;
my $sHeader = "\n\n# $sTime\n";
my $sLogFile = "$sLogDir/$sResName"."_online\.log";
my $sCommandOutFile = "$sLogDir/$sResName"."_online\.out";
if (!-e $sLogFile ){
$sHeader = "#
# Log Name:     $sLogFile
# System:       $lsOsDetails[1]
# SysInfo:      $lsOsDetails[0]:$lsOsDetails[1],$lsOsDetails[3],$lsOsDetails[2],$lsOsDetails[-1]
# Created:      $sTime
# \n";
$sHeader =~ s/SunOS/Solaris/g;
print $sLogDir;
}
sysopen ( LOG, $sLogFile,
          O_WRONLY|O_SYNC|O_CREAT|O_APPEND, 0641 ) ||
die "Failed to create and open file  [$sLogFile]: $!\n";

print LOG $sHeader;
my $sCmdToRun     = "";
my $sCommandLine  = "";
my $sRedirection = "";
my $iCommandReturnCode = 0;
  my ( $sName,
       $sPassword,
       $iUid,
       $iGid,
       $iQuota,
       $sComment,
       $sGcos,
       $sHome,
       $sUserShell,
       $sExpire ) = getpwnam( $sUser );
 
  if ($bIsBackground){
    $sRedirection = "> $sCommandOutFile 2>&1 &";
  }
 
  if (defined $sEnvFile) {
    
    if( $sUserShell =~ /(.*)\/bin\/.*csh$/ )
    {
      print LOG "\nUser [$sUser] has csh derived native shell [$sUserShell]";
      #---------------------------------------------------------------
      # Shell is a csh varient, so we should use the 'source' command.
      #---------------------------------------------------------------
      $sCmdToRun .= "setenv USER $sUser; setenv HOME $sHome; source $sEnvFile;";
      if ($bIsBackground){
        $sRedirection = "& > $sCommandOutFile 2>&1";
      }
    }
    else
    {
      print LOG "User [$sUser] has sh derived native shell [$sUserShell]";
      #---------------------------------------------------------
      # Shell is one of the non-C type shells. Use '.' to source 
      # in the env file.
      #---------------------------------------------------------
      $sCmdToRun .= "USER=$sUser; HOME=$sHome; export USER HOME; . $sEnvFile ;";
      if ($bIsBackground){
        $sRedirection = "> $sCommandOutFile 2>&1 &";
      }
    }
  }

  if ( ! -e $sCommand ) {
                     print LOG "\nFile [$sCommand] does not exist" ;
    exit -1 ;
  } 
  elsif ( ! -x $sCommand ) {
                     print LOG "\nFile [$sCommand] is not executable"; 
    exit -1 ;
  } 
  else {
    if( defined $sCommandArgs || $sCommandArgs ne "" ) {
      $sCmdToRun .= "$sCommand $sCommandArgs" ;
    }
    else {
      $sCmdToRun .= $sCommand ;
    }
  }

  $sCommandLine = "$sCmdToRun $sRedirection";
    print LOG "\nCommand [$sCommandLine]";
    system("$sCommandLine");
    $iCommandReturnCode = $? >> 8;
                     

  print LOG "\nCommand [$sCommandLine] returned code [$iCommandReturnCode]";

  exit $iCommandReturnCode;
